const chalk = require('chalk');
const { LOG_PREFIX } = require('./constant');

class Log {
  constructor(quiet = false) {
    // 开启颜色
    chalk.level = 1
    this.log = quiet ? () => {} : console.log;
    const levelMap = {
      info: 'blue',
      warn: 'yellow',
      error: 'red',
      success: 'green',
    };

    Object.keys(levelMap).forEach((level) => {
      const levelInfo = chalk[levelMap[level]](
        `${LOG_PREFIX} ${level.toUpperCase()}:`
      );
      this[level] = (...args) => {
        if (level === 'error') return console.log(levelInfo, ...args);
        this.log(levelInfo, ...args);
      };
    });
  }

  clear() {
    // clear screen
    process.stdout.write('\u001b[2J');
    process.stdout.write('\u001b[1;1H');
  }

  cmd(str) {
    console.log('  $', chalk.blue(str));
  }

  raw(...args) {
    console.log(...args);
  }
  
  rawBlue(...args){
    console.log(chalk.blue(...args))
  }

  rawGreen(...args){
    console.log(chalk.green(...args))
  }

  rawBgGreen(...args){
    console.log(chalk.green.bold.bgBlack(...args))
  }
  rawBgRed(...args){
    console.log(chalk.red.bold.bgBlack(...args))
  }
  rawBgYellow(...args){
    console.log(chalk.yellow.bold.bgBlack(...args))
  }
}
const log = new Log()
module.exports = log;
